﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace CustomFilteringControl
{
    public class Activity : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        private string name;
        private AgendaActivityType activityType;

        public string Name
        {
            get { return this.name; }
            set
            {
                if (value != this.name)
                {
                    this.name = value;
                    this.OnPropertyChanged("Name");
                }
            }
        }

        public AgendaActivityType ActivityType
        {
            get { return this.activityType; }
            set
            {
                if (value != this.activityType)
                {
                    this.activityType = value;
                    this.OnPropertyChanged("ActivityType");
                }
            }
        }

        public Activity()
        {

        }

        public Activity(string name, AgendaActivityType activityType)
        {
            this.name = name;
            this.activityType = activityType;
        }

        protected virtual void OnPropertyChanged(PropertyChangedEventArgs args)
        {
            PropertyChangedEventHandler handler = this.PropertyChanged;
            if (handler != null)
            {
                handler(this, args);
            }
        }

        private void OnPropertyChanged(string propertyName)
        {
            this.OnPropertyChanged(new PropertyChangedEventArgs(propertyName));
        }

        public override string ToString()
        {
            return this.Name;
        }

        public static ObservableCollection<Activity> GetActivities()
        {
            ObservableCollection<Activity> activities = new ObservableCollection<Activity>();
            Activity activity;

            activity = new Activity("Relaxation", AgendaActivityType.FreeTime);
            activities.Add(activity);

            activity = new Activity("First teambuilding", AgendaActivityType.TeamBuilding);
            activities.Add(activity);

            activity = new Activity("Release time!", AgendaActivityType.Work);
            activities.Add(activity);

            return activities;
        }
    }
}
