﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.GridView;
using Telerik.Windows.Data;

namespace CustomFilteringControl
{
    /// <summary>
    /// Interaction logic for SalusGridViewCustomFilteringControl.xaml
    /// </summary>
    public partial class SalusGridViewCustomFilteringControl : UserControl, IFilteringControl
    {
        private GridViewBoundColumnBase column;
        private CompositeFilterDescriptor compositeFilter;
        private Telerik.Windows.Data.FilterDescriptor filterDescriptor;

        /// <summary>
        /// Gets or sets a value indicating whether the filtering is active.
        /// </summary>
        public bool IsActive
        {
            get { return (bool)GetValue(IsActiveProperty); }
            set { SetValue(IsActiveProperty, value); }
        }

        /// <summary>
        /// Identifies the <see cref="IsActive"/> dependency property.
        /// </summary>
        public static readonly DependencyProperty IsActiveProperty =
            DependencyProperty.Register(
                "IsActive",
                typeof(bool),
                typeof(SalusGridViewCustomFilteringControl),
                new System.Windows.PropertyMetadata(false));


        public IEnumerable<AgendaActivityType> AgendaItemTypes
        {
            get { return (IEnumerable<AgendaActivityType>)GetValue(AgendaItemTypesProperty); }
            set { SetValue(AgendaItemTypesProperty, value); }
        }

        public static readonly DependencyProperty AgendaItemTypesProperty = DependencyProperty.Register(
            "AgendaItemTypes", typeof(IEnumerable<AgendaActivityType>), typeof(SalusGridViewCustomFilteringControl), new FrameworkPropertyMetadata(default(IEnumerable<AgendaActivityType>)));

        public AgendaActivityType SelectedAgendaItemType
        {
            get { return (AgendaActivityType)this.selectedAgenda.SelectedItem; }
            set { SetValue(SelectedAgendaItemTypeProperty, value); }
        }

        public static readonly DependencyProperty SelectedAgendaItemTypeProperty = DependencyProperty.Register(
            "SelectedAgendaItemType", typeof(AgendaActivityType), typeof(SalusGridViewCustomFilteringControl), new FrameworkPropertyMetadata(default(AgendaActivityType)));

        public SalusGridViewCustomFilteringControl()
        {
            InitializeComponent();
            RootLayout.DataContext = this;
            AgendaItemTypes = Enum.GetValues(typeof(AgendaActivityType)).Cast<AgendaActivityType>();
        }

        public void Prepare(Telerik.Windows.Controls.GridViewColumn column)
        {
            this.column = column as GridViewBoundColumnBase;
            if (this.column == null)
            {
                return;
            }

            if (this.compositeFilter == null)
            {
                this.CreateFilters();
            }

            if (this.SelectedAgendaItemType != null)
            {
                this.filterDescriptor.Value = this.SelectedAgendaItemType;
            }
            else
            {
                this.filterDescriptor.Value = AgendaActivityType.FreeTime;
            }
        }

        private void CreateFilters()
        {
            string dataMember = this.column.DataMemberBinding.Path.Path;

            this.compositeFilter = new CompositeFilterDescriptor();

            this.filterDescriptor = new Telerik.Windows.Data.FilterDescriptor(dataMember
                , Telerik.Windows.Data.FilterOperator.IsEqualTo
                , null);
            this.compositeFilter.FilterDescriptors.Add(this.filterDescriptor);
        }

        private void OnClear(object sender, RoutedEventArgs e)
        {
            if (this.column.DataControl.FilterDescriptors.Contains(this.compositeFilter))
            {
                this.column.DataControl.FilterDescriptors.Remove(this.compositeFilter);
            }

            this.SelectedAgendaItemType = AgendaActivityType.FreeTime;

            this.IsActive = false;
        }

        private void selectedAgenda_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (this.filterDescriptor != null)
            {
                this.filterDescriptor.Value = this.SelectedAgendaItemType;

                if (!this.column.DataControl.FilterDescriptors.Contains(this.compositeFilter))
                {
                    this.column.DataControl.FilterDescriptors.Add(this.compositeFilter);
                }

                this.IsActive = true;
            }
        }
    }
}
